@@ -29,17 +29,24 @@ class Connection(object):
                  organization_to_manage=None,
                  scope='admin'):
 
+        self.__scope = scope
+        self.__session_expires = 0
+        self.__organization_to_manage = organization_to_manage
+        self.__link_cache = {}
+        self.__token_type = None
+        self.__access_token = None
+
         if profile:
             import os.path
             import codecs
             profiles = {}
 
-            if os.path.isfile('.aiqpy_profiles'):
-                profiles.update(json.load(open('.aiqpy_profiles')))
             if os.path.isfile(os.path.expanduser('~/.aiqpy_profiles')):
                 profiles.update(json.load(
                     open(os.path.expanduser('~/.aiqpy_profiles')))
                 )
+            if os.path.isfile('.aiqpy_profiles'):
+                profiles.update(json.load(open('.aiqpy_profiles')))
 
             if profile not in profiles:
                 raise LoginError('Profile "%s" not found' % profile)
@@ -55,6 +62,7 @@ class Connection(object):
                 raise LoginError('Incorrect profile. Required fields: ' +
                                  ', '.join(required_keys))
 
+            # Add the profile data to the object as private variables.
             for (key, value) in profile_data.iteritems():
                 setattr(self, '_'+self.__class__.__name__+'__'+key, value)
 
@@ -69,11 +77,6 @@ class Connection(object):
         else:
             raise LoginError('You need to provide username, password, ' +
                              'organization and platform or a profile')
-        self.__session_expires = 0
-        self.__organization_to_manage = organization_to_manage
-        self.__link_cache = {}
-        self.__token_type = None
-        self.__access_token = None
 
     def __enter__(self):
         return self
